@@ -725,7 +725,7 @@ class IF(SystemIF, CommandIF, QueryIF, EventIF, Service_Application_Base_sample.
                     # print(x)
                     s = x.split(':')
                     s_name = s[6]
-                    s_module = importlib.import_module("pyrois_common.{}".format(str(d[x]["module"])))
+                    s_module = importlib.import_module("{}".format(str(d[x]["module"])))
                     s_method = getattr(s_module, d[x]["class"])
                     self.sub_engine[s_name] = s_method(d[x]["url"],logger=self.logger_client,event_queue=self.sub_event_q)
                 self.logger.info("self.sub_engine: {}".format(str(self.sub_engine)))
@@ -733,7 +733,7 @@ class IF(SystemIF, CommandIF, QueryIF, EventIF, Service_Application_Base_sample.
                     # print(x)
                     c = y.split(':')
                     c_name = c[6]
-                    c_module = importlib.import_module("pyrois_common.{}".format(d[y]["module"])) # PYTHONPATHでコンポーネントのディレクトリ指定　export PYTHONPATH="$(pwd):$PYTHONPATH"
+                    c_module = importlib.import_module("{}".format(d[y]["module"])) # PYTHONPATHでコンポーネントのディレクトリ指定　export PYTHONPATH="$(pwd):$PYTHONPATH"
                     # c_module = importlib.import_module("{}".format(d[y]["module"])) 
                     c_method = getattr(c_module, d[y]["class"])
                     if c_name in event_occur_component:
