@@ -46,7 +46,7 @@ class Service_Application_IF(RoIS_Service.Service_Application_Base):
             try:
                 msg = self._proxy_sa.poll_event()
                 # print("sa: try poll_event")
-            except ConnectionRefusedError:
+            except:
                 # print("sa: error poll_event")
                 self.logger.debug("poll_event: xmlrpc error")
                 return
